GLASS = b"\uf000"
MUSIC = b"\uf001"
SEARCH = b"\uf002"
ENVELOPE_O = b"\uf003"
HEART = b"\uf004"
STAR = b"\uf005"
STAR_O = b"\uf006"
USER = b"\uf007"
FILM = b"\uf008"
TH_LARGE = b"\uf009"
TH = b"\uf00a"
TH_LIST = b"\uf00b"
CHECK = b"\uf00c"
TIMES = b"\uf00d"
SEARCH_PLUS = b"\uf00e"
SEARCH_MINUS = b"\uf010"
POWER_OFF = b"\uf011"
SIGNAL = b"\uf012"
COG = b"\uf013"
TRASH_O = b"\uf014"
HOME = b"\uf015"
FILE_O = b"\uf016"
CLOCK_O = b"\uf017"
ROAD = b"\uf018"
DOWNLOAD = b"\uf019"
ARROW_CIRCLE_O_DOWN = b"\uf01a"
ARROW_CIRCLE_O_UP = b"\uf01b"
INBOX = b"\uf01c"
PLAY_CIRCLE_O = b"\uf01d"
REPEAT = b"\uf01e"
REFRESH = b"\uf021"
LIST_ALT = b"\uf022"
LOCK = b"\uf023"
FLAG = b"\uf024"
HEADPHONES = b"\uf025"
VOLUME_OFF = b"\uf026"
VOLUME_DOWN = b"\uf027"
VOLUME_UP = b"\uf028"
QRCODE = b"\uf029"
BARCODE = b"\uf02a"
TAG = b"\uf02b"
TAGS = b"\uf02c"
BOOK = b"\uf02d"
BOOKMARK = b"\uf02e"
PRINT = b"\uf02f"
CAMERA = b"\uf030"
FONT = b"\uf031"
BOLD = b"\uf032"
ITALIC = b"\uf033"
TEXT_HEIGHT = b"\uf034"
TEXT_WIDTH = b"\uf035"
ALIGN_LEFT = b"\uf036"
ALIGN_CENTER = b"\uf037"
ALIGN_RIGHT = b"\uf038"
ALIGN_JUSTIFY = b"\uf039"
LIST = b"\uf03a"
OUTDENT = b"\uf03b"
INDENT = b"\uf03c"
VIDEO_CAMERA = b"\uf03d"
PICTURE_O = b"\uf03e"
PENCIL = b"\uf040"
MAP_MARKER = b"\uf041"
ADJUST = b"\uf042"
TINT = b"\uf043"
PENCIL_SQUARE_O = b"\uf044"
SHARE_SQUARE_O = b"\uf045"
CHECK_SQUARE_O = b"\uf046"
ARROWS = b"\uf047"
STEP_BACKWARD = b"\uf048"
FAST_BACKWARD = b"\uf049"
BACKWARD = b"\uf04a"
PLAY = b"\uf04b"
PAUSE = b"\uf04c"
STOP = b"\uf04d"
FORWARD = b"\uf04e"
FAST_FORWARD = b"\uf050"
STEP_FORWARD = b"\uf051"
EJECT = b"\uf052"
CHEVRON_LEFT = b"\uf053"
CHEVRON_RIGHT = b"\uf054"
PLUS_CIRCLE = b"\uf055"
MINUS_CIRCLE = b"\uf056"
TIMES_CIRCLE = b"\uf057"
CHECK_CIRCLE = b"\uf058"
QUESTION_CIRCLE = b"\uf059"
INFO_CIRCLE = b"\uf05a"
CROSSHAIRS = b"\uf05b"
TIMES_CIRCLE_O = b"\uf05c"
CHECK_CIRCLE_O = b"\uf05d"
BAN = b"\uf05e"
ARROW_LEFT = b"\uf060"
ARROW_RIGHT = b"\uf061"
ARROW_UP = b"\uf062"
ARROW_DOWN = b"\uf063"
SHARE = b"\uf064"
EXPAND = b"\uf065"
COMPRESS = b"\uf066"
PLUS = b"\uf067"
MINUS = b"\uf068"
ASTERISK = b"\uf069"
EXCLAMATION_CIRCLE = b"\uf06a"
GIFT = b"\uf06b"
LEAF = b"\uf06c"
FIRE = b"\uf06d"
EYE = b"\uf06e"
EYE_SLASH = b"\uf070"
EXCLAMATION_TRIANGLE = b"\uf071"
PLANE = b"\uf072"
CALENDAR = b"\uf073"
RANDOM = b"\uf074"
COMMENT = b"\uf075"
MAGNET = b"\uf076"
CHEVRON_UP = b"\uf077"
CHEVRON_DOWN = b"\uf078"
RETWEET = b"\uf079"
SHOPPING_CART = b"\uf07a"
FOLDER = b"\uf07b"
FOLDER_OPEN = b"\uf07c"
ARROWS_V = b"\uf07d"
ARROWS_H = b"\uf07e"
BAR_CHART = b"\uf080"
TWITTER_SQUARE = b"\uf081"
FACEBOOK_SQUARE = b"\uf082"
CAMERA_RETRO = b"\uf083"
KEY = b"\uf084"
COGS = b"\uf085"
COMMENTS = b"\uf086"
THUMBS_O_UP = b"\uf087"
THUMBS_O_DOWN = b"\uf088"
STAR_HALF = b"\uf089"
HEART_O = b"\uf08a"
SIGN_OUT = b"\uf08b"
LINKEDIN_SQUARE = b"\uf08c"
THUMB_TACK = b"\uf08d"
EXTERNAL_LINK = b"\uf08e"
SIGN_IN = b"\uf090"
TROPHY = b"\uf091"
GITHUB_SQUARE = b"\uf092"
UPLOAD = b"\uf093"
LEMON_O = b"\uf094"
PHONE = b"\uf095"
SQUARE_O = b"\uf096"
BOOKMARK_O = b"\uf097"
PHONE_SQUARE = b"\uf098"
TWITTER = b"\uf099"
FACEBOOK = b"\uf09a"
GITHUB = b"\uf09b"
UNLOCK = b"\uf09c"
CREDIT_CARD = b"\uf09d"
RSS = b"\uf09e"
HDD_O = b"\uf0a0"
BULLHORN = b"\uf0a1"
BELL = b"\uf0f3"
CERTIFICATE = b"\uf0a3"
HAND_O_RIGHT = b"\uf0a4"
HAND_O_LEFT = b"\uf0a5"
HAND_O_UP = b"\uf0a6"
HAND_O_DOWN = b"\uf0a7"
ARROW_CIRCLE_LEFT = b"\uf0a8"
ARROW_CIRCLE_RIGHT = b"\uf0a9"
ARROW_CIRCLE_UP = b"\uf0aa"
ARROW_CIRCLE_DOWN = b"\uf0ab"
GLOBE = b"\uf0ac"
WRENCH = b"\uf0ad"
TASKS = b"\uf0ae"
FILTER = b"\uf0b0"
BRIEFCASE = b"\uf0b1"
ARROWS_ALT = b"\uf0b2"
USERS = b"\uf0c0"
LINK = b"\uf0c1"
CLOUD = b"\uf0c2"
FLASK = b"\uf0c3"
SCISSORS = b"\uf0c4"
FILES_O = b"\uf0c5"
PAPERCLIP = b"\uf0c6"
FLOPPY_O = b"\uf0c7"
SQUARE = b"\uf0c8"
BARS = b"\uf0c9"
LIST_UL = b"\uf0ca"
LIST_OL = b"\uf0cb"
STRIKETHROUGH = b"\uf0cc"
UNDERLINE = b"\uf0cd"
TABLE = b"\uf0ce"
MAGIC = b"\uf0d0"
TRUCK = b"\uf0d1"
PINTEREST = b"\uf0d2"
PINTEREST_SQUARE = b"\uf0d3"
GOOGLE_PLUS_SQUARE = b"\uf0d4"
GOOGLE_PLUS = b"\uf0d5"
MONEY = b"\uf0d6"
CARET_DOWN = b"\uf0d7"
CARET_UP = b"\uf0d8"
CARET_LEFT = b"\uf0d9"
CARET_RIGHT = b"\uf0da"
COLUMNS = b"\uf0db"
SORT = b"\uf0dc"
SORT_DESC = b"\uf0dd"
SORT_ASC = b"\uf0de"
ENVELOPE = b"\uf0e0"
LINKEDIN = b"\uf0e1"
UNDO = b"\uf0e2"
GAVEL = b"\uf0e3"
TACHOMETER = b"\uf0e4"
COMMENT_O = b"\uf0e5"
COMMENTS_O = b"\uf0e6"
BOLT = b"\uf0e7"
SITEMAP = b"\uf0e8"
UMBRELLA = b"\uf0e9"
CLIPBOARD = b"\uf0ea"
LIGHTBULB_O = b"\uf0eb"
EXCHANGE = b"\uf0ec"
CLOUD_DOWNLOAD = b"\uf0ed"
CLOUD_UPLOAD = b"\uf0ee"
USER_MD = b"\uf0f0"
STETHOSCOPE = b"\uf0f1"
SUITCASE = b"\uf0f2"
BELL_O = b"\uf0a2"
COFFEE = b"\uf0f4"
CUTLERY = b"\uf0f5"
FILE_TEXT_O = b"\uf0f6"
BUILDING_O = b"\uf0f7"
HOSPITAL_O = b"\uf0f8"
AMBULANCE = b"\uf0f9"
MEDKIT = b"\uf0fa"
FIGHTER_JET = b"\uf0fb"
BEER = b"\uf0fc"
H_SQUARE = b"\uf0fd"
PLUS_SQUARE = b"\uf0fe"
ANGLE_DOUBLE_LEFT = b"\uf100"
ANGLE_DOUBLE_RIGHT = b"\uf101"
ANGLE_DOUBLE_UP = b"\uf102"
ANGLE_DOUBLE_DOWN = b"\uf103"
ANGLE_LEFT = b"\uf104"
ANGLE_RIGHT = b"\uf105"
ANGLE_UP = b"\uf106"
ANGLE_DOWN = b"\uf107"
DESKTOP = b"\uf108"
LAPTOP = b"\uf109"
TABLET = b"\uf10a"
MOBILE = b"\uf10b"
CIRCLE_O = b"\uf10c"
QUOTE_LEFT = b"\uf10d"
QUOTE_RIGHT = b"\uf10e"
SPINNER = b"\uf110"
CIRCLE = b"\uf111"
REPLY = b"\uf112"
GITHUB_ALT = b"\uf113"
FOLDER_O = b"\uf114"
FOLDER_OPEN_O = b"\uf115"
SMILE_O = b"\uf118"
FROWN_O = b"\uf119"
MEH_O = b"\uf11a"
GAMEPAD = b"\uf11b"
KEYBOARD_O = b"\uf11c"
FLAG_O = b"\uf11d"
FLAG_CHECKERED = b"\uf11e"
TERMINAL = b"\uf120"
CODE = b"\uf121"
REPLY_ALL = b"\uf122"
STAR_HALF_O = b"\uf123"
LOCATION_ARROW = b"\uf124"
CROP = b"\uf125"
CODE_FORK = b"\uf126"
CHAIN_BROKEN = b"\uf127"
QUESTION = b"\uf128"
INFO = b"\uf129"
EXCLAMATION = b"\uf12a"
SUPERSCRIPT = b"\uf12b"
SUBSCRIPT = b"\uf12c"
ERASER = b"\uf12d"
PUZZLE_PIECE = b"\uf12e"
MICROPHONE = b"\uf130"
MICROPHONE_SLASH = b"\uf131"
SHIELD = b"\uf132"
CALENDAR_O = b"\uf133"
FIRE_EXTINGUISHER = b"\uf134"
ROCKET = b"\uf135"
MAXCDN = b"\uf136"
CHEVRON_CIRCLE_LEFT = b"\uf137"
CHEVRON_CIRCLE_RIGHT = b"\uf138"
CHEVRON_CIRCLE_UP = b"\uf139"
CHEVRON_CIRCLE_DOWN = b"\uf13a"
HTML5 = b"\uf13b"
CSS3 = b"\uf13c"
ANCHOR = b"\uf13d"
UNLOCK_ALT = b"\uf13e"
BULLSEYE = b"\uf140"
ELLIPSIS_H = b"\uf141"
ELLIPSIS_V = b"\uf142"
RSS_SQUARE = b"\uf143"
PLAY_CIRCLE = b"\uf144"
TICKET = b"\uf145"
MINUS_SQUARE = b"\uf146"
MINUS_SQUARE_O = b"\uf147"
LEVEL_UP = b"\uf148"
LEVEL_DOWN = b"\uf149"
CHECK_SQUARE = b"\uf14a"
PENCIL_SQUARE = b"\uf14b"
EXTERNAL_LINK_SQUARE = b"\uf14c"
SHARE_SQUARE = b"\uf14d"
COMPASS = b"\uf14e"
CARET_SQUARE_O_DOWN = b"\uf150"
CARET_SQUARE_O_UP = b"\uf151"
CARET_SQUARE_O_RIGHT = b"\uf152"
EUR = b"\uf153"
GBP = b"\uf154"
USD = b"\uf155"
INR = b"\uf156"
JPY = b"\uf157"
RUB = b"\uf158"
KRW = b"\uf159"
BTC = b"\uf15a"
FILE = b"\uf15b"
FILE_TEXT = b"\uf15c"
SORT_ALPHA_ASC = b"\uf15d"
SORT_ALPHA_DESC = b"\uf15e"
SORT_AMOUNT_ASC = b"\uf160"
SORT_AMOUNT_DESC = b"\uf161"
SORT_NUMERIC_ASC = b"\uf162"
SORT_NUMERIC_DESC = b"\uf163"
THUMBS_UP = b"\uf164"
THUMBS_DOWN = b"\uf165"
YOUTUBE_SQUARE = b"\uf166"
YOUTUBE = b"\uf167"
XING = b"\uf168"
XING_SQUARE = b"\uf169"
YOUTUBE_PLAY = b"\uf16a"
DROPBOX = b"\uf16b"
STACK_OVERFLOW = b"\uf16c"
INSTAGRAM = b"\uf16d"
FLICKR = b"\uf16e"
ADN = b"\uf170"
BITBUCKET = b"\uf171"
BITBUCKET_SQUARE = b"\uf172"
TUMBLR = b"\uf173"
TUMBLR_SQUARE = b"\uf174"
LONG_ARROW_DOWN = b"\uf175"
LONG_ARROW_UP = b"\uf176"
LONG_ARROW_LEFT = b"\uf177"
LONG_ARROW_RIGHT = b"\uf178"
APPLE = b"\uf179"
WINDOWS = b"\uf17a"
ANDROID = b"\uf17b"
LINUX = b"\uf17c"
DRIBBBLE = b"\uf17d"
SKYPE = b"\uf17e"
FOURSQUARE = b"\uf180"
TRELLO = b"\uf181"
FEMALE = b"\uf182"
MALE = b"\uf183"
GRATIPAY = b"\uf184"
SUN_O = b"\uf185"
MOON_O = b"\uf186"
ARCHIVE = b"\uf187"
BUG = b"\uf188"
VK = b"\uf189"
WEIBO = b"\uf18a"
RENREN = b"\uf18b"
PAGELINES = b"\uf18c"
STACK_EXCHANGE = b"\uf18d"
ARROW_CIRCLE_O_RIGHT = b"\uf18e"
ARROW_CIRCLE_O_LEFT = b"\uf190"
CARET_SQUARE_O_LEFT = b"\uf191"
DOT_CIRCLE_O = b"\uf192"
WHEELCHAIR = b"\uf193"
VIMEO_SQUARE = b"\uf194"
TRY = b"\uf195"
PLUS_SQUARE_O = b"\uf196"
SPACE_SHUTTLE = b"\uf197"
SLACK = b"\uf198"
ENVELOPE_SQUARE = b"\uf199"
WORDPRESS = b"\uf19a"
OPENID = b"\uf19b"
UNIVERSITY = b"\uf19c"
GRADUATION_CAP = b"\uf19d"
YAHOO = b"\uf19e"
GOOGLE = b"\uf1a0"
REDDIT = b"\uf1a1"
REDDIT_SQUARE = b"\uf1a2"
STUMBLEUPON_CIRCLE = b"\uf1a3"
STUMBLEUPON = b"\uf1a4"
DELICIOUS = b"\uf1a5"
DIGG = b"\uf1a6"
PIED_PIPER_PP = b"\uf1a7"
PIED_PIPER_ALT = b"\uf1a8"
DRUPAL = b"\uf1a9"
JOOMLA = b"\uf1aa"
LANGUAGE = b"\uf1ab"
FAX = b"\uf1ac"
BUILDING = b"\uf1ad"
CHILD = b"\uf1ae"
PAW = b"\uf1b0"
SPOON = b"\uf1b1"
CUBE = b"\uf1b2"
CUBES = b"\uf1b3"
BEHANCE = b"\uf1b4"
BEHANCE_SQUARE = b"\uf1b5"
STEAM = b"\uf1b6"
STEAM_SQUARE = b"\uf1b7"
RECYCLE = b"\uf1b8"
CAR = b"\uf1b9"
TAXI = b"\uf1ba"
TREE = b"\uf1bb"
SPOTIFY = b"\uf1bc"
DEVIANTART = b"\uf1bd"
SOUNDCLOUD = b"\uf1be"
DATABASE = b"\uf1c0"
FILE_PDF_O = b"\uf1c1"
FILE_WORD_O = b"\uf1c2"
FILE_EXCEL_O = b"\uf1c3"
FILE_POWERPOINT_O = b"\uf1c4"
FILE_IMAGE_O = b"\uf1c5"
FILE_ARCHIVE_O = b"\uf1c6"
FILE_AUDIO_O = b"\uf1c7"
FILE_VIDEO_O = b"\uf1c8"
FILE_CODE_O = b"\uf1c9"
VINE = b"\uf1ca"
CODEPEN = b"\uf1cb"
JSFIDDLE = b"\uf1cc"
LIFE_RING = b"\uf1cd"
CIRCLE_O_NOTCH = b"\uf1ce"
REBEL = b"\uf1d0"
EMPIRE = b"\uf1d1"
GIT_SQUARE = b"\uf1d2"
GIT = b"\uf1d3"
HACKER_NEWS = b"\uf1d4"
TENCENT_WEIBO = b"\uf1d5"
QQ = b"\uf1d6"
WEIXIN = b"\uf1d7"
PAPER_PLANE = b"\uf1d8"
PAPER_PLANE_O = b"\uf1d9"
HISTORY = b"\uf1da"
CIRCLE_THIN = b"\uf1db"
HEADER = b"\uf1dc"
PARAGRAPH = b"\uf1dd"
SLIDERS = b"\uf1de"
SHARE_ALT = b"\uf1e0"
SHARE_ALT_SQUARE = b"\uf1e1"
BOMB = b"\uf1e2"
FUTBOL_O = b"\uf1e3"
TTY = b"\uf1e4"
BINOCULARS = b"\uf1e5"
PLUG = b"\uf1e6"
SLIDESHARE = b"\uf1e7"
TWITCH = b"\uf1e8"
YELP = b"\uf1e9"
NEWSPAPER_O = b"\uf1ea"
WIFI = b"\uf1eb"
CALCULATOR = b"\uf1ec"
PAYPAL = b"\uf1ed"
GOOGLE_WALLET = b"\uf1ee"
CC_VISA = b"\uf1f0"
CC_MASTERCARD = b"\uf1f1"
CC_DISCOVER = b"\uf1f2"
CC_AMEX = b"\uf1f3"
CC_PAYPAL = b"\uf1f4"
CC_STRIPE = b"\uf1f5"
BELL_SLASH = b"\uf1f6"
BELL_SLASH_O = b"\uf1f7"
TRASH = b"\uf1f8"
COPYRIGHT = b"\uf1f9"
AT = b"\uf1fa"
EYEDROPPER = b"\uf1fb"
PAINT_BRUSH = b"\uf1fc"
BIRTHDAY_CAKE = b"\uf1fd"
AREA_CHART = b"\uf1fe"
PIE_CHART = b"\uf200"
LINE_CHART = b"\uf201"
LASTFM = b"\uf202"
LASTFM_SQUARE = b"\uf203"
TOGGLE_OFF = b"\uf204"
TOGGLE_ON = b"\uf205"
BICYCLE = b"\uf206"
BUS = b"\uf207"
IOXHOST = b"\uf208"
ANGELLIST = b"\uf209"
CC = b"\uf20a"
ILS = b"\uf20b"
MEANPATH = b"\uf20c"
BUYSELLADS = b"\uf20d"
CONNECTDEVELOP = b"\uf20e"
DASHCUBE = b"\uf210"
FORUMBEE = b"\uf211"
LEANPUB = b"\uf212"
SELLSY = b"\uf213"
SHIRTSINBULK = b"\uf214"
SIMPLYBUILT = b"\uf215"
SKYATLAS = b"\uf216"
CART_PLUS = b"\uf217"
CART_ARROW_DOWN = b"\uf218"
DIAMOND = b"\uf219"
SHIP = b"\uf21a"
USER_SECRET = b"\uf21b"
MOTORCYCLE = b"\uf21c"
STREET_VIEW = b"\uf21d"
HEARTBEAT = b"\uf21e"
VENUS = b"\uf221"
MARS = b"\uf222"
MERCURY = b"\uf223"
TRANSGENDER = b"\uf224"
TRANSGENDER_ALT = b"\uf225"
VENUS_DOUBLE = b"\uf226"
MARS_DOUBLE = b"\uf227"
VENUS_MARS = b"\uf228"
MARS_STROKE = b"\uf229"
MARS_STROKE_V = b"\uf22a"
MARS_STROKE_H = b"\uf22b"
NEUTER = b"\uf22c"
GENDERLESS = b"\uf22d"
FACEBOOK_OFFICIAL = b"\uf230"
PINTEREST_P = b"\uf231"
WHATSAPP = b"\uf232"
SERVER = b"\uf233"
USER_PLUS = b"\uf234"
USER_TIMES = b"\uf235"
BED = b"\uf236"
VIACOIN = b"\uf237"
TRAIN = b"\uf238"
SUBWAY = b"\uf239"
MEDIUM = b"\uf23a"
Y_COMBINATOR = b"\uf23b"
OPTIN_MONSTER = b"\uf23c"
OPENCART = b"\uf23d"
EXPEDITEDSSL = b"\uf23e"
BATTERY_FULL = b"\uf240"
BATTERY_THREE_QUARTERS = b"\uf241"
BATTERY_HALF = b"\uf242"
BATTERY_QUARTER = b"\uf243"
BATTERY_EMPTY = b"\uf244"
MOUSE_POINTER = b"\uf245"
I_CURSOR = b"\uf246"
OBJECT_GROUP = b"\uf247"
OBJECT_UNGROUP = b"\uf248"
STICKY_NOTE = b"\uf249"
STICKY_NOTE_O = b"\uf24a"
CC_JCB = b"\uf24b"
CC_DINERS_CLUB = b"\uf24c"
CLONE = b"\uf24d"
BALANCE_SCALE = b"\uf24e"
HOURGLASS_O = b"\uf250"
HOURGLASS_START = b"\uf251"
HOURGLASS_HALF = b"\uf252"
HOURGLASS_END = b"\uf253"
HOURGLASS = b"\uf254"
HAND_ROCK_O = b"\uf255"
HAND_PAPER_O = b"\uf256"
HAND_SCISSORS_O = b"\uf257"
HAND_LIZARD_O = b"\uf258"
HAND_SPOCK_O = b"\uf259"
HAND_POINTER_O = b"\uf25a"
HAND_PEACE_O = b"\uf25b"
TRADEMARK = b"\uf25c"
REGISTERED = b"\uf25d"
CREATIVE_COMMONS = b"\uf25e"
GG = b"\uf260"
GG_CIRCLE = b"\uf261"
TRIPADVISOR = b"\uf262"
ODNOKLASSNIKI = b"\uf263"
ODNOKLASSNIKI_SQUARE = b"\uf264"
GET_POCKET = b"\uf265"
WIKIPEDIA_W = b"\uf266"
SAFARI = b"\uf267"
CHROME = b"\uf268"
FIREFOX = b"\uf269"
OPERA = b"\uf26a"
INTERNET_EXPLORER = b"\uf26b"
TELEVISION = b"\uf26c"
CONTAO = b"\uf26d"
_500PX = b"\uf26e"
AMAZON = b"\uf270"
CALENDAR_PLUS_O = b"\uf271"
CALENDAR_MINUS_O = b"\uf272"
CALENDAR_TIMES_O = b"\uf273"
CALENDAR_CHECK_O = b"\uf274"
INDUSTRY = b"\uf275"
MAP_PIN = b"\uf276"
MAP_SIGNS = b"\uf277"
MAP_O = b"\uf278"
MAP = b"\uf279"
COMMENTING = b"\uf27a"
COMMENTING_O = b"\uf27b"
HOUZZ = b"\uf27c"
VIMEO = b"\uf27d"
BLACK_TIE = b"\uf27e"
FONTICONS = b"\uf280"
REDDIT_ALIEN = b"\uf281"
EDGE = b"\uf282"
CREDIT_CARD_ALT = b"\uf283"
CODIEPIE = b"\uf284"
MODX = b"\uf285"
FORT_AWESOME = b"\uf286"
USB = b"\uf287"
PRODUCT_HUNT = b"\uf288"
MIXCLOUD = b"\uf289"
SCRIBD = b"\uf28a"
PAUSE_CIRCLE = b"\uf28b"
PAUSE_CIRCLE_O = b"\uf28c"
STOP_CIRCLE = b"\uf28d"
STOP_CIRCLE_O = b"\uf28e"
SHOPPING_BAG = b"\uf290"
SHOPPING_BASKET = b"\uf291"
HASHTAG = b"\uf292"
BLUETOOTH = b"\uf293"
BLUETOOTH_B = b"\uf294"
PERCENT = b"\uf295"
GITLAB = b"\uf296"
WPBEGINNER = b"\uf297"
WPFORMS = b"\uf298"
ENVIRA = b"\uf299"
UNIVERSAL_ACCESS = b"\uf29a"
WHEELCHAIR_ALT = b"\uf29b"
QUESTION_CIRCLE_O = b"\uf29c"
BLIND = b"\uf29d"
AUDIO_DESCRIPTION = b"\uf29e"
VOLUME_CONTROL_PHONE = b"\uf2a0"
BRAILLE = b"\uf2a1"
ASSISTIVE_LISTENING_SYSTEMS = b"\uf2a2"
AMERICAN_SIGN_LANGUAGE_INTERPRETING = b"\uf2a3"
DEAF = b"\uf2a4"
GLIDE = b"\uf2a5"
GLIDE_G = b"\uf2a6"
SIGN_LANGUAGE = b"\uf2a7"
LOW_VISION = b"\uf2a8"
VIADEO = b"\uf2a9"
VIADEO_SQUARE = b"\uf2aa"
SNAPCHAT = b"\uf2ab"
SNAPCHAT_GHOST = b"\uf2ac"
SNAPCHAT_SQUARE = b"\uf2ad"
PIED_PIPER = b"\uf2ae"
FIRST_ORDER = b"\uf2b0"
YOAST = b"\uf2b1"
THEMEISLE = b"\uf2b2"
GOOGLE_PLUS_OFFICIAL = b"\uf2b3"
FONT_AWESOME = b"\uf2b4"
HANDSHAKE_O = b"\uf2b5"
ENVELOPE_OPEN = b"\uf2b6"
ENVELOPE_OPEN_O = b"\uf2b7"
LINODE = b"\uf2b8"
ADDRESS_BOOK = b"\uf2b9"
ADDRESS_BOOK_O = b"\uf2ba"
ADDRESS_CARD = b"\uf2bb"
ADDRESS_CARD_O = b"\uf2bc"
USER_CIRCLE = b"\uf2bd"
USER_CIRCLE_O = b"\uf2be"
USER_O = b"\uf2c0"
ID_BADGE = b"\uf2c1"
ID_CARD = b"\uf2c2"
ID_CARD_O = b"\uf2c3"
QUORA = b"\uf2c4"
FREE_CODE_CAMP = b"\uf2c5"
TELEGRAM = b"\uf2c6"
THERMOMETER_FULL = b"\uf2c7"
THERMOMETER_THREE_QUARTERS = b"\uf2c8"
THERMOMETER_HALF = b"\uf2c9"
THERMOMETER_QUARTER = b"\uf2ca"
THERMOMETER_EMPTY = b"\uf2cb"
SHOWER = b"\uf2cc"
BATH = b"\uf2cd"
PODCAST = b"\uf2ce"
WINDOW_MAXIMIZE = b"\uf2d0"
WINDOW_MINIMIZE = b"\uf2d1"
WINDOW_RESTORE = b"\uf2d2"
WINDOW_CLOSE = b"\uf2d3"
WINDOW_CLOSE_O = b"\uf2d4"
BANDCAMP = b"\uf2d5"
GRAV = b"\uf2d6"
ETSY = b"\uf2d7"
IMDB = b"\uf2d8"
RAVELRY = b"\uf2d9"
EERCAST = b"\uf2da"
MICROCHIP = b"\uf2db"
SNOWFLAKE_O = b"\uf2dc"
SUPERPOWERS = b"\uf2dd"
WPEXPLORER = b"\uf2de"
MEETUP = b"\uf2e0"
